/* © 2024 Dummy */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the TestAdDummy repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

#import <UIKit/UIKit.h>
#import "DummyAdConstants.h"
#import "DummyAdVoidBlock.h"

@class DummyAdModalState;
@class DummyAdAdConfiguration;
@class DummyAdInterstitialDisplayProperties;

typedef void (^DummyAdModalStatePopHandler)(DummyAdModalState * _Nullable poppedState);
typedef void (^DummyAdModalStateAppLeavingHandler)(DummyAdModalState * _Nullable leavingState);

@interface DummyAdModalState: NSObject

@property (nonatomic, strong, nullable, readonly) DummyAdAdConfiguration *adConfiguration;
@property (nonatomic, strong, nullable, readonly) DummyAdInterstitialDisplayProperties *displayProperties;
@property (nonatomic, strong, nullable, readonly) UIView *view;

@property (nonatomic, copy, nonnull) DummyAdMRAIDState mraidState;

@property (nonatomic, copy, nullable, readonly) DummyAdModalStatePopHandler onStatePopFinished;
@property (nonatomic, copy, nullable, readonly) DummyAdModalStateAppLeavingHandler onStateHasLeftApp;

// Used to transfer delegate function to another object, rather then current delegate for next states pushed on top
// ref: MOBILE-5849
@property (nonatomic, copy, nullable, readonly) DummyAdModalStatePopHandler nextOnStatePopFinished;
@property (nonatomic, copy, nullable, readonly) DummyAdModalStateAppLeavingHandler nextOnStateHasLeftApp;

@property (nonatomic, strong, nullable) DummyAdVoidBlock onModalPushedBlock;

@property (nonatomic, assign, readonly, getter=isRotationEnabled) BOOL rotationEnabled;

- (nonnull instancetype)init NS_UNAVAILABLE;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable DummyAdAdConfiguration *)adConfiguration
                         displayProperties:(nullable DummyAdInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable DummyAdModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable DummyAdModalStateAppLeavingHandler)onStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable DummyAdAdConfiguration *)adConfiguration
                         displayProperties:(nullable DummyAdInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable DummyAdModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable DummyAdModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable DummyAdModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable DummyAdModalStateAppLeavingHandler)nextOnStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable DummyAdAdConfiguration *)adConfiguration
                         displayProperties:(nullable DummyAdInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable DummyAdModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable DummyAdModalStateAppLeavingHandler)onStateHasLeftApp
                        onModalPushedBlock:(nullable DummyAdVoidBlock)onModalPushedBlock;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable DummyAdAdConfiguration *)adConfiguration
                         displayProperties:(nullable DummyAdInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable DummyAdModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable DummyAdModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable DummyAdModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable DummyAdModalStateAppLeavingHandler)nextOnStateHasLeftApp
                        onModalPushedBlock:(nullable DummyAdVoidBlock)onModalPushedBlock;

@end
